/*
 * LWdatagrid.js
 * This the datagrid widget of the LightWeigthComponents project
 * (https://sourceforge.net/projects/lwcomponents/)
 *
 * @copyright (C) 2005 Luca Mariano <luca.mariano@email.it>
 * @license GPL [http://www.fsf.org/licensing/licenses/gpl.txt]
 * @author Luca Mariano <luca.mariano@email.it>
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

var LWdatagrid_idx = 0;

/*
 * LWdatagrid
 * Ctor
 * optionally accepts the columns definition array
 *
 */
function LWdatagrid(doc)
{
    this.name = 'LWdatagrid_'+LWdatagrid_idx++;
    this.columns = new Array();
    this.data = new Array();
    this.selectObj = null;
    this.attributeList = new Array();
    this.doc = doc;
    this.sortCol = null;
    this.descending = false;
    this.instanceName = null;

  this.doc.write('<link rel="stylesheet" type="text/css" href="../css/LWdatagrid.css" />\n');

    function _removeRow(key)
    {
         for (var i=0; i<this.selectObj.length; i++)
         {
            if (this.selectObj.options[i].value == key )
            {
                this.selectObj.remove(i);
                this.data[key] = null;
            }
          }

    }

    function _addRow(row)
    {
    var key = row.shift();

     if  (this.data  == null)
            this.data = new Array();
    this.data[key] = new Array();
    this.data[key] = row;

    for (var j=0;j<  this.columns.length;j++)
    {
        var l = this.columns[j][1];
        if (row[j] == null)
            row[j] = "-";

        if (row[j].length < l)
        {
            while (row[j].length < l)
            {
                row[j] = row[j] + "\u00A0";
            }
        } else if (row[j].length > l) {

            row[j] = row[j].substring(0,l);
        }
    }

    this.selectObj.options[this.selectObj.length] = new Option(row.join("\u007C"),key);
    }

    function _selectAll()
    {
        for (var i=this.selectObj.length-1;i>=0;i--)
        {
        this.selectObj.options[i].selected=true;
        }
    }

    function _getSortFunc()
    {
        // try to guess the right column type...
        var exampleData = this.data[0][this.sortCol];
        if (IsNumeric(exampleData))
        {
            return compareNums;

        } else {
            return compareString;
        }


     }


    this._addRow = _addRow;
    this._removeRow = _removeRow;
    this._selectAll = _selectAll;
    this._getSortFunc = _getSortFunc;
}


/*
 * addRow
 * add a single row to the table
 *
 */
LWdatagrid.prototype.addRow = function(row) {

    if (isArray(row)) {
    var vals = new Array(row.length);
    for (var idx=0; idx<row.length; idx++)
    {
        vals[idx] = row[idx];

    }
    this._addRow(vals);
    }
}




/*
 * empty
 * empty the table
 *
 */
LWdatagrid.prototype.empty = function()
{
    for (var i=this.selectObj.length;i>=0;i--)
    {
        this.selectObj.options[i]=null;
    }
    this.selectObj.length=0;
    this.data = null;
}



/*
 * getSelection
 * return an array of selected keys
 *
 */
LWdatagrid.prototype.getSelection = function()
{
var ret = new Array();
        for ( i=0; i<this.selectObj.length ; i++) {
	    if (this.selectObj.options[ i ].selected)
	    {
		var row = this.selectObj[i].value;
		var rowArray = row.split('|');
		ret.push(rowArray[0]);
	     }
        }

return ret;
}



/*
 * init
 * init the table, to be called after body loading
 *
 */
LWdatagrid.prototype.init = function(instName)
{
    this.instanceName = instName;
    var docObj = this.doc;
    this.selectObj = docObj.getElementById(this.name);
    var parentObj = this.selectObj.parentNode;
    var tdObj = Array(this.columns.length);
    var btnObj = Array(this.columns.length);
    var tableObj = docObj.createElement("TABLE");

    tableObj.setAttribute("border","0");
    tableObj.setAttribute("cellspacing","0");
    tableObj.setAttribute("cellpadding","0");
    tbodyObj = docObj.createElement("TBODY");

    var trObj = docObj.createElement("TR");
    tbodyObj.appendChild(trObj);

    for (var j=0;j<  this.columns.length;j++)
    {
    if (j%3 == 0)
            diff = 2;
    else
            diff = 3;

    var l = this.columns[j][1];
    var str = this.columns[j][0];
    if (str.length < l)
    {
            while (str.length < (l-diff))
            {
            str = str + " ";
            }
    } else if (str.length > (l-diff)) {

            str = str.substring(0,l);
    }

    tdObj[j] = docObj.createElement("TD");

    btnObj[j] = docObj.createElement("INPUT");
    btnObj[j].setAttribute("type","button");
    btnObj[j].setAttribute("id","header_"+j);
    btnObj[j].setAttribute("value",str);
    btnObj[j].setAttribute("class","datagridhead");
    btnObj[j].setAttribute("onclick",this.instanceName+".sortOnColumn("+(j+1)+");");

    //   var l = mylengths[j];
    //tdObj[j].nodeValue = btnObj[j];
    tdObj[j].appendChild ( btnObj[j]);
    trObj.appendChild(tdObj[j]);
    }
    tableObj.appendChild(tbodyObj);

    parentObj.insertBefore(tableObj,this.selectObj);
    for (var i=this.selectObj.length;i>=0;i--)
    {
    this.selectObj.options[i]=null;
    }
}




LWdatagrid.prototype.removeRow = function(key) {
    if (isString(key))
    {
         this._removeRow(key);
    } else if (isArray(key))
    {
        for ( j=0; j<key.length ; j++)
        {
            this._removeRow(key[j])
        }
    }

}



LWdatagrid.prototype.selectAll = function()
{
    this._selectAll();
}




LWdatagrid.prototype.setColumns = function(columns) {
    this.columns = columns;
}




LWdatagrid.prototype.show = function (values) {

     if  (this.data  == null)
            this.data = new Array();

    for (var idx=0; idx<values.length; idx++)
    {
        this.data[idx] = values[idx];

    }
    for (var idx=0; idx<values.length; idx++)
    {
        this.addRow(values[idx]);

    }

}


LWdatagrid.prototype.toString = function() {

    var ret = '<select multiple="multiple" id="'+this.name+'" class="datagrid" ';
    if (isArray(this.attributeList))
    {
        for (var idx=0; idx<this.attributeList.length; idx++)
        {
            ret += this.attributeList[idx][0] + '="' + this.attributeList[idx][1] + '" ';
        }
    }

    ret +='>\n';
    ret +='<option></option>\n';
    ret +='</select>\n';

    return ret;
}

LWdatagrid.prototype.addAttribute = function(act) {

    this.attributeList.push(act);
}

LWdatagrid.prototype.sortOnColumn = function(col)
{
    if (col == this.sortCol)
        this.descending = !this.descending;
    else
        this.descending = false;


    this.sortCol = col;
    sortFunc = this._getSortFunc();

    var values = new Array();

    for (var idx=0; idx<this.data.length; idx++)
    {
        values.push(this.data[idx][this.sortCol]);
    }

    values.sort(sortFunc);
    if (this.descending)
        values.reverse();


    var dataCache = new Array();

    for (var idx=0; idx<values.length; idx++)
    {
        for (var jdx=0; jdx<values.length; jdx++)
        {
            if (this.data[jdx][this.sortCol] == values[idx])
                {
                dataCache.push(this.data[jdx]);
                break;
                }
        }
    }

    this.empty();

    this.data = new Array();
    for (var idx=0; idx<dataCache.length; idx++)
    {
        this.data.push(dataCache[idx]);
    }

/*     for (var j=0;j<  this.columns.length;j++)
    {
    if (j == this.sortCol)
        this.doc.getElementById('header_'+j).value = this.doc.getElementById('header_'+j).value + ' A';

    } */
    this.show(this.data);
}


LWdatagrid.prototype.printView = function()
{
    var ret = '<html>\n<body onload="self.print();">\n<table>\n';
    ret += '<th>ID</th>\n';
    for (var j=0;j<  this.columns.length;j++)
    {
        ret += '<th>\n';
        ret += this.columns[j][0]+'\n';
        ret += '</th>\n';
    }
    for (var i=0; i<this.data.length; i++)
    {
    	ret += '<tr>\n';
	for (var j=0;j<  this.columns.length+1;j++)
    	{
	    ret += '<td>\n';
	    ret += this.data[i][j]+'\n';
	    ret += '</td>\n';
    	}
    	ret += '</tr>\n';
    }
    ret += '</table>\n</body>\n</html>\n';
    var printWin = window.open('#','printView','menubar=no,toolbar=no,location=no,resizable=yes,scrollbars=yes,status=no,height=300,width=300');
    printWin.document.open();
    printWin.document.write(ret);
    printWin.document.close();

}






















