/*
 * LWdesktop.js
 * This the desktop widget of the LightWeigthComponents project
 * (https://sourceforge.net/projects/lwcomponents/)
 *
 * @copyright (C) 2006-2005 Luca Mariano <luca.mariano@email.it>
 * @license GPL [http://www.fsf.org/licensing/licenses/gpl.txt]
 * @author Luca Mariano <luca.mariano@email.it>
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


/*
 * LWdesktop
 * Ctor
 *
 */
function LWdesktop(doc)
{
    this.name = 'LWdesktop';
    this.doc = doc;
    this.doc.write('<link rel="stylesheet" type="text/css" href="../css/LWdesktop.css" />\n');

function loadpage(url,divObj){
var page_request = false
if (window.XMLHttpRequest) // if Mozilla, Safari etc
page_request = new XMLHttpRequest()
else if (window.ActiveXObject){ // if IE
try {
page_request = new ActiveXObject("Msxml2.XMLHTTP")
}
catch (e){
try{
page_request = new ActiveXObject("Microsoft.XMLHTTP")
}
catch (e){}
}
}
else
return false
page_request.onreadystatechange=function(){
	_loadpage(page_request,divObj,url)
}
page_request.open('GET', url, true)
page_request.send(null)
}

function _loadpage(page_request,divObj,url){
if (page_request.readyState == 4 && (page_request.status==200 || window.location.href.indexOf("http")==-1))
{
	divObj.innerHTML = page_request.responseText;
	onUrlLoaded(url);
}
}

function _addWindow(wName,wUrl,wWidth, wHeight) {

	var oDiv = document.createElement("div");
	oDiv.setAttribute('id' , wName);
	oDiv.style.width = wWidth + "px";
	oDiv.style.height = wHeight + "px";
	oDiv.style.border = "0";
	loadpage(wUrl,oDiv);
	new JSWindow(wName, oDiv, 10, 10);
}

this._addWindow = _addWindow;
}

/*
 * addRow
 * add a single row to the table
 *
 */
LWdesktop.prototype.addWindow = function(wName,wUrl,wWidth, wHeight) {
        this._addWindow(wName,wUrl,wWidth, wHeight);
}



function JSWindow(title, oContent, x, y)
{
	// save arguments
	this.title = title;
	this.oContent = oContent;

	// initialization
	this.mx = 0;
	this.my = 0;

	// create table for window with title-bar and content
	this.oTable = document.createElement("table");
	this.oTable.border = 1;

	// set the position of the window
	this.oTable.style.position = "absolute";
	this.oTable.style.left = x + "px";
	this.oTable.style.top = y + "px";

	// set background to white (default is transparent)
	this.oTable.style.backgroundColor = "white";

	// link from the table to the JSWindow object
	this.oTable.jsWindow = this;

	// if anywhere in the table are is clicked, bring the window to front.
	this.oTable.onmousedown = JSWindow.prototype.onBringToFront;

	// append to document body
	document.body.appendChild(this.oTable);

	// add row for title bar
	var oTR = this.oTable.insertRow(0);
	oTR.className = "LWwindowTitleStyle";



//if the browser is IE4+
oTR.onselectstart=new Function ("return false")

//if the browser is NS6
if (window.sidebar){
oTR.onmousedown=disabletext
oTR.onclick=reEnable
}


	// title
	var oTD = oTR.insertCell(0);
	oTD.innerHTML = title;
	oTD.jsWindow = this;
	oTD.onmousedown = JSWindow.prototype.tdOnMouseDown;

	// minimize
	this.oMinTD = oTR.insertCell(1);
	this.oMinTD.innerHTML = "_";
	this.oMinTD.className = "LWwindowMinimizeBtn";
	this.oMinTD.onmousedown = JSWindow.prototype.onMinimize;
	this.oMinTD.jsWindow = this;

	// close
	oTD = oTR.insertCell(2);
	oTD.innerHTML = "X";
	oTD.className = "LWwindowCloseBtn";
	oTD.jsWindow = this;
	oTD.onmousedown = JSWindow.prototype.onClose;

	// add row for window content
	// a single cell the same width as the title bar row
	oTR = this.oTable.insertRow(1);
	oTD = oTR.insertCell(0);
	oTD.colSpan = 3;
	oTD.appendChild(oContent);
}

JSWindow.prototype.onBringToFront = function()
{
	this.jsWindow.bringToFront();
}
JSWindow.prototype.bringToFront = function()
{
	// if not already the last child of the document.body, make it so
	if ( document.body.childNodes[document.body.childNodes.length-1] !== this.oTable )
	{
		// move to bottom of document
		document.body.appendChild(this.oTable);
	}
}

JSWindow.prototype.tdOnMouseDown = function()
{
	this.jsWindow.onMouseDown();
}
JSWindow.prototype.onMouseDown = function()
{
	// record that an onmousedown has just occurred
	this.bDown = true;

	// link from body to this JSWindow object
	document.body.jsWindow = this;

	// save body mouse handlers
	this.saveMouseMove = document.body.onmousemove;
	this.saveMouseUp = document.body.onmouseup;

	// set new handlers.
	document.body.onmousemove = JSWindow.prototype.bodyOnMouseMove;
	document.body.onmouseup = JSWindow.prototype.bodyOnMouseUp;
}
JSWindow.prototype.bodyOnMouseMove = function(evt)
{
	var e = window.event ? window.event : evt;
	this.jsWindow.onMouseMove(e);
}
JSWindow.prototype.onMouseMove = function(evt)
{
	// if mouse not down, stop the move (for IE only)
	if ( (document.all) && !(evt.button & 1) )
	{
		this.onMouseUp();
		return;
	}
	if ( this.bDown )
	{
		this.dx = parseInt(this.oTable.style.left, 10) - evt.clientX;
		this.dy = parseInt(this.oTable.style.top, 10) - evt.clientY;
		this.bDown = false;
	}
	else
	{
		this.oTable.style.left = Math.max((this.dx + evt.clientX),0) + "px";
		this.oTable.style.top = Math.max((this.dy + evt.clientY),0) + "px";
	}
}
JSWindow.prototype.bodyOnMouseUp = function()
{
	this.jsWindow.onMouseUp();
}
JSWindow.prototype.onMouseUp = function()
{
	document.body.onmouseup = this.saveMouseUp;
	document.body.onmousemove = this.saveMouseMove;
	document.body.jsWindow = null;
}
JSWindow.prototype.onMinimize = function()
{
	this.jsWindow.minimize();
}
JSWindow.prototype.minimize = function()
{
	// hide the content
	this.oContent.style.visibility = "hidden";
	this.oContent.style.position = "absolute";
	document.body.appendChild(this.oContent);

	this.oTable.deleteRow(1);

	// save current position
	this.saveX = this.oTable.style.left;
	this.saveY = this.oTable.style.top;

	// get the "window bar"
	if ( !window.jsWindowBar )
	{
		window.jsWindowBar = document.createElement("div");
		document.body.appendChild(window.jsWindowBar);
	}

	window.jsWindowBar.appendChild(this.oTable);
	this.oTable.style.position = "static";
	this.oTable.style.left = "0px";
	this.oTable.style.top = "0px";

	this.oMinTD.innerHTML = "#";
	this.oMinTD.onmousedown = JSWindow.prototype.onMaximize;
}
JSWindow.prototype.onMaximize = function()
{
	this.jsWindow.maximize();
}
JSWindow.prototype.maximize = function()
{
	document.body.appendChild(this.oTable);
	this.oTable.style.position = "absolute";

	this.oTable.style.left = this.saveX;
	this.oTable.style.top = this.saveY;

	// add the content again.
	oTR = this.oTable.insertRow(1);
	oTD = oTR.insertCell(0);
	oTD.colSpan = 3;

	oTD.appendChild(this.oContent);
	this.oContent.style.position = "static";
	this.oContent.style.visibility = "visible";

	this.oMinTD.innerHTML = "_";
	this.oMinTD.onmousedown = JSWindow.prototype.onMinimize;
}
JSWindow.prototype.onMaximize = function()
{
	this.jsWindow.maximize();
}
JSWindow.prototype.close = function()
{
	// remove content from browser document
	this.oContent.parentNode.removeChild(this.oContent);

	// remove from browser document
	this.oTable.parentNode.removeChild(this.oTable);
}
JSWindow.prototype.onClose = function()
{
	this.jsWindow.close();
}


function disabletext(e){
return false
}

function reEnable(){
return true
}







